The VOC Developer and User community
====================================

.. note::
    If you're a newcomer to the project looking for how to start contributing,
    check out the `First Timers Guide`_.

VOC is part of the `BeeWare suite`_. You can talk to the community through:

* `@pybeeware on Twitter`_

* `Our Gitter channel`_ for discussion about development and general help around this project or anything under the Beeware suite of projects. 

Code of Conduct
---------------

The BeeWare community has a strict `Code of Conduct`_. All users and developers are expected to adhere to this code.

If you have any concerns about this code of conduct, or you wish to report a violation of this code, please contact the project founder `Russell Keith-Magee`.

Contributing
------------

If you experience problems with VOC, `log them on GitHub`_. If you
want to contribute code, please `fork the code`_ and `submit a pull request`_.

.. _BeeWare suite: http://pybee.org
.. _Read The Docs: https://voc.readthedocs.io
.. _@pybeeware on Twitter: https://twitter.com/pybeeware
.. _Our Gitter channel: https://gitter.im/pybee/general
.. _log them on Github: https://github.com/pybee/voc/issues
.. _fork the code: https://github.com/pybee/voc
.. _submit a pull request: https://github.com/pybee/voc/pulls

.. _Code of Conduct: https://pybee.org/community/behavior/code-of-conduct/
.. _Russell Keith-Magee: mailto:russell@keith-magee.com
.. _First Timers Guide: http://pybee.org/contributing/how/first-time/what/voc/
